@@ -1,6 +1,6 @@
 #######################################################################
 # rEMM - Extensible Markov Model (EMM) for Data Stream Clustering in R
-# Copyrigth (C) 2011 Michael Hahsler
+# Copyright (C) 2011 Michael Hahsler
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -18,22 +18,30 @@
 
 
 setMethod("prune", signature(x = "EMM"),
-	function(x, count_threshold, clusters = TRUE, 
-		transitions = FALSE, copy = TRUE, compact = TRUE){
+  function(x,
+    count_threshold,
+    clusters = TRUE,
+    transitions = FALSE,
+    copy = TRUE,
+    compact = TRUE) {
+    if (copy)
+      x <- copy(x)
 
-	    if(copy) x <- copy(x)
+    if (clusters && nclusters(x) > 0)
+      x <- remove_clusters(x,
+        rare_clusters(x, count_threshold = count_threshold),
+        copy = FALSE)
 
-	    if(clusters && nclusters(x)>0) 
-		x <- remove_clusters(x, 
-		    rare_clusters(x, count_threshold=count_threshold),
-		    copy=FALSE)
+    if (transitions && ntransitions(x) > 0)
+      x <- remove_transitions(x,
+        rare_transitions(x, count_threshold = count_threshold),
+        copy = FALSE)
 
-	    if(transitions && ntransitions(x)>0) 
-		x <- remove_transitions(x, 
-		    rare_transitions(x, count_threshold=count_threshold),
-		    copy=FALSE)
+    if (compact)
+      x <- compact(x)
 
-	    if(compact) x <- compact(x)
-
-	    if(copy) x else invisible(x)
-	})
+    if (copy)
+      x
+    else
+      invisible(x)
+  })
